@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Moo;
 use strictures 2;
@@ -26,6 +26,17 @@ has verbose => (
 
 
 
+sub b2int {
+    my ($self, $sequences) = @_;
+    my @intervals;
+    for my $i (@$sequences) {
+        my $string = join '', @$i;
+        push @intervals, [ map { length $_ } grep { $_ } split /(10*)/, $string ];
+    }
+    return \@intervals;
+}
+
+
 sub cfcv {
     my ($self, @terms) = @_;
 
@@ -544,17 +555,6 @@ sub _allowed { # is p one of the parts?
     return any { $p == $_ } @$parts;
 }
 
-
-sub b2int {
-    my ($self, $sequences) = @_;
-    my @intervals;
-    for my $i (@$sequences) {
-        my $string = join '', @$i;
-        push @intervals, [ map { length $_ } grep { $_ } split /(10*)/, $string ];
-    }
-    return \@intervals;
-}
-
 1;
 
 __END__
@@ -569,7 +569,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -605,6 +605,18 @@ Show progress. * This is not showing anything yet, however.
 
 Create a new C<Music::CreatingRhythms> object.
 
+=head2 b2int
+
+  $intervals = $mcr->b2int($sequences);
+
+Convert binary B<sequences> of the form C<[[1,0],[1,0,0]]> into a set
+of intervals of the form C<[[2],[3]]>.
+
+Examples:
+
+  $got = $mcr->b2int([[1,1,0,1,0,0]]);     # [[1,2,3]]
+  $got = $mcr->b2int([[1],[1,0],[1,0,0]]); # [[1],[2],[3]]
+
 =head2 cfcv
 
   $convergent = $mcr->cfcv(@terms);
@@ -929,23 +941,11 @@ Examples:
   $got = $mcr->rotate_n(4, $parts); # 0 1 0 0 1
   $got = $mcr->rotate_n(5, $parts); # 1 0 1 0 0
 
-=head2 b2int
-
-  $intervals = $mcr->b2int($sequences);
-
-Convert binary B<sequences> of the form C<[[1,0],[1,0,0]]> into a set
-of intervals of the form C<[[2],[3]]>.
-
-Examples:
-
-  $got = $mcr->b2int([[1,1,0,1,0,0]]);     # [[1,2,3]]
-  $got = $mcr->b2int([[1],[1,0],[1,0,0]]); # [[1],[2],[3]]
-
 =head1 SEE ALSO
 
-L<https://abrazol.com/books/rhythm1/> "Creating Rhythms", the book.
+L<https://abrazol.com/books/rhythm1/> - "Creating Rhythms", the book.
 
-L<https://ology.github.io/2023/03/02/creating-rhythms-with-perl/>, my write-up.
+L<https://ology.github.io/2023/03/02/creating-rhythms-with-perl/> - my write-up.
 
 The F<t/01-methods.t> and F<eg/*> programs included with this distribution.
 
